Module barriers

Module barriers 

Functions

optimization_barrier_u8
Identity function accepting a u8 as input and outputting that same u8 as output, while blocking the compiler from applying optimizations across this node in the data dependence graph.