Functions
- optimization_
barrier_ u8 - Identity function accepting a
u8as input and outputting that sameu8as output, while blocking the compiler from applying optimizations across this node in the data dependence graph.
u8 as input and outputting that same u8 as
output, while blocking the compiler from applying optimizations across this node in the data
dependence graph.